@@ -179,7 +179,7 @@ def update_authorized_keys():
 
     # Write authorized_keys
     fd = open(os.path.join(home_path, '.ssh', 'authorized_keys'), 'w')
-    os.fchmod(fd, 0o600)
+    os.fchmod(fd.fileno(), 0o600)
     fd.write(authorized_keys)
     fd.close()
 
